@@ -1,7 +1,7 @@
 package String::Elide::Parts;
 
 our $DATE = '2017-01-28'; # DATE
-our $VERSION = '0.05'; # VERSION
+our $VERSION = '0.06'; # VERSION
 
 use 5.010001;
 use strict;
@@ -44,6 +44,7 @@ sub elide {
     $opts //= {};
     my $truncate  = $opts->{truncate} // 'right';
     my $marker = $opts->{marker} // '..';
+    my $default_prio = $opts->{default_prio} // 1;
 
     # split into parts by priority
     my @parts;
@@ -75,16 +76,12 @@ sub elide {
                 if $parts_attrs[$i] =~ /\bprio(?:rity)?=(?:"([^"]*)"|(\S+))/;
             $parts_attrs[$i] = $attrs;
         } else {
-            $parts_attrs[$i] = {prio=>1};
+            $parts_attrs[$i] = {prio=>$default_prio};
         }
     }
 
     #use DD; dd \@parts; dd \@parts_attrs;
 
-    # used to flip and flop between eliding left and right end, used when
-    # truncate is 'ends'
-    my $flip = 0;
-
     # elide and truncate prio by prio until str is short enough
   PRIO:
     while (1) {
@@ -179,11 +176,11 @@ String::Elide::Parts - Elide a string with multiple parts of different prioritie
 
 =head1 VERSION
 
-This document describes version 0.05 of String::Elide::Parts (from Perl distribution String-Elide-Parts), released on 2017-01-28.
+This document describes version 0.06 of String::Elide::Parts (from Perl distribution String-Elide-Parts), released on 2017-01-28.
 
 =head1 SYNOPSIS
 
- use String::Elide qw(elide);
+ use String::Elide::Parts qw(elide);
 
 Eliding string with no parts:
 
@@ -246,6 +243,8 @@ Known options:
 
 =item * truncate => 'left'|'middle'|'middle'|'ends' (default: 'right')
 
+=item * default_prio => int (default: 1)
+
 =back
 
 =head1 HOMEPAGE
